@@ -1,8 +1,9 @@
 pub mod errors;
-mod instructions;
-pub mod pda;
 pub mod state;
 
+mod instructions;
+mod pda;
+
 use {anchor_lang::prelude::*, instructions::*, state::*};
 
 declare_id!("7fNcRaPYHSBbqZuM5E87s3k6hX9DfPWCwiNbmLib2XvZ");
