@@ -14,19 +14,6 @@ pub struct Daemon {
     pub bump: u8,
 }
 
-impl std::fmt::Display for Daemon {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(
-            f,
-            "{{
-    owner: {},
-    task_count: {}
-}}",
-            self.owner, self.task_count,
-        )
-    }
-}
-
 impl TryFrom<Vec<u8>> for Daemon {
     type Error = ProgramError;
     fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
@@ -35,7 +22,7 @@ impl TryFrom<Vec<u8>> for Daemon {
 }
 
 impl Daemon {
-    pub fn find_pda(owner: Pubkey) -> PDA {
+    pub fn pda(owner: Pubkey) -> PDA {
         Pubkey::find_program_address(&[SEED_DAEMON, owner.as_ref()], &crate::ID)
     }
 }
